namespace FitConnect.Services;

public interface IOAuthService: IRestCallService {
    bool IsAuthenticated { get; }
    

    /// <summary>
    ///     Requesting an OAuth token from the FitConnect API.
    ///     <para>
    ///         You can get the Client ID and Client Secret from the FitConnect Self Service portal
    ///         under <br />
    ///         https://portal.auth-testing.fit-connect.fitko.dev
    ///     </para>
    /// </summary>
    /// <param name="clientId">Your client Id</param>
    /// <param name="clientSecret">Your client Secret</param>
    /// <param name="scope">Scope if needed</param>
    /// <returns>The received token or null</returns>
    Task AuthenticateAsync(
        string? scope = null);

    public void EnsureAuthenticated();
}
